@@ -196,6 +196,7 @@ void run_part(char *progname)
     exit(1);
   }
   else if (!pid) {
+    setsid();
     if (report_mode) {
       if (dup2(pout[1], STDOUT_FILENO) == -1 ||
 	  dup2(perr[1], STDERR_FILENO) == -1) {
@@ -345,13 +346,17 @@ void run_parts(char *dirname)
     strcat(filename, "/");
     strcat(filename, namelist[i]->d_name);
 
-    result = stat(filename, &st);
+    result = lstat(filename, &st);
     if (result < 0) {
-      error("failed to stat component %s: %s", filename, strerror(errno));
-      exit(1);
+      if (exit_on_error_mode) {
+        error("failed to lstat component %s: %s", filename, strerror(errno));
+        exit(1);
+      }
+      else
+	return;
     }
 
-    if (S_ISREG(st.st_mode)) {
+    if (S_ISREG(st.st_mode) || S_ISLNK(st.st_mode)) {
       if (!access(filename, X_OK)) {
 	if (test_mode) {
 	  printf("%s\n", filename);
@@ -372,6 +377,12 @@ void run_parts(char *dirname)
 	  printf("%s\n", filename);
 	}
       }
+      else if (S_ISLNK(st.st_mode)) {
+	if (!list_mode) {
+	  printf("run-parts: component %s is a broken symbolic link\n",filename);
+	  exitstatus = 1;
+	}
+      }
     }
     else if (!S_ISDIR(st.st_mode)) {
       if (!list_mode) {
